Package: equatiomatic
Title: Transform Models into 'LaTeX' Equations
Version: 0.4.8
Authors@R: 
    c(person(given = "Daniel",
             family = "Anderson",
             role = "aut",
             email = "daniela@uoregon.edu",
             comment = c(ORCID = "0000-0003-4699-4680")),
      person(given = "Andrew",
             family = "Heiss",
             role = "aut",
             email = "andrew@andrewheiss.com",
             comment = c(ORCID = "0000-0002-3948-3914")),
      person(given = "Jay",
             family = "Sumners",
             role = "aut",
             email = "jay.sumners@gmail.com"),
      person(given = "Joshua",
             family = "Rosenberg",
             role = "ctb",
             email = "jmrosenberg@utk.edu",
             comment = c(ORCID = "0000-0003-2170-0447")),
      person(given = "Jonathan",
             family = "Sidi",
             role = "ctb",
             email = "yonis@metrumrg.com",
             comment = c(ORCID = "0000-0002-4222-1819")),
      person(given = "Ellis",
             family = "Hughes",
             role = "ctb",
             email = "ellishughes@live.com",
             comment = c(ORCID = "0000-0003-0637-4436")),
      person(given = "Thomas",
             family = "Fung",
             role = "ctb",
             email = "thomas.fung.dr@gmail.com",
             comment = c(ORCID = "0000-0003-2601-0728")),
      person(given = "Reza",
             family = "Norouzian",
             role = "ctb",
             email = "rnorouzian@gmail.com",
             comment = c(ORCID = "0000-0002-0531-6886")),
      person(given = "Indrajeet",
             family = "Patil",
             role = "ctb",
             email = "patilindrajeet.science@gmail.com",
             comment = c(ORCID = "0000-0003-1995-6531")),
      person(given = "Quinn",
             family = "White",
             role = "ctb",
             email = "quinnarlise@gmail.com",
             comment = c(ORCID = "0000-0001-5399-0237")),
      person(given = "David",
             family = "Kane",
             role = "ctb",
             email = "dave.kane@gmail.com"),
      person(given = "Philippe",
             family = "Grosjean",
             role = "cre",
             email = "phgrosjean@sciviews.org",
             comment = c(ORCID = "0000-0002-2694-9471")),
      person(given = "Teun",
             family = "van den Brand",
             role = "ctb",
             email = "t.vandenbrand@nki.nl",
             comment = c(ORCID = "0000-0002-9335-7468")),
      person(given = "Guyliann",
             family = "Engels",
             role = "ctb",
             email = "guyliann.engels@umons.ac.be",
             comment = c(ORCID = "0000-0001-9514-1014")))
Maintainer: Philippe Grosjean <phgrosjean@sciviews.org>
Description: The goal of 'equatiomatic' is to reduce the pain
    associated with writing 'LaTeX' formulas from fitted models. The
    primary function of the package, extract_eq(), takes a fitted model
    object as its input and returns the corresponding 'LaTeX' code for the
    model.
License: CC BY 4.0
Depends: R (>= 3.3.0)
URL: https://github.com/datalorax/equatiomatic,
        https://datalorax.github.io/equatiomatic/
BugReports: https://github.com/datalorax/equatiomatic/issues
Imports: broom (>= 0.7.0), broom.mixed, shiny, knitr, rmarkdown, stats,
        utils
Suggests: covr, shinyWidgets, forecast (>= 8.13), ggplot2 (>= 3.3.3),
        latex2exp (>= 0.4.0), lme4, MASS, ordinal, parsnip, recipes,
        workflows, testthat (>= 3.0.0), gtsummary, spelling
VignetteBuilder: knitr
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.2
Config/testthat/edition: 3
Config/testthat/parallel: true
Language: en-US
NeedsCompilation: no
Packaged: 2026-04-10 16:47:37 UTC; phgrosjean
Author: Daniel Anderson [aut] (ORCID: <https://orcid.org/0000-0003-4699-4680>),
  Andrew Heiss [aut] (ORCID: <https://orcid.org/0000-0002-3948-3914>),
  Jay Sumners [aut],
  Joshua Rosenberg [ctb] (ORCID: <https://orcid.org/0000-0003-2170-0447>),
  Jonathan Sidi [ctb] (ORCID: <https://orcid.org/0000-0002-4222-1819>),
  Ellis Hughes [ctb] (ORCID: <https://orcid.org/0000-0003-0637-4436>),
  Thomas Fung [ctb] (ORCID: <https://orcid.org/0000-0003-2601-0728>),
  Reza Norouzian [ctb] (ORCID: <https://orcid.org/0000-0002-0531-6886>),
  Indrajeet Patil [ctb] (ORCID: <https://orcid.org/0000-0003-1995-6531>),
  Quinn White [ctb] (ORCID: <https://orcid.org/0000-0001-5399-0237>),
  David Kane [ctb],
  Philippe Grosjean [cre] (ORCID:
    <https://orcid.org/0000-0002-2694-9471>),
  Teun van den Brand [ctb] (ORCID:
    <https://orcid.org/0000-0002-9335-7468>),
  Guyliann Engels [ctb] (ORCID: <https://orcid.org/0000-0001-9514-1014>)
Repository: CRAN
Date/Publication: 2026-04-10 17:20:02 UTC
Built: R 4.5.2; ; 2026-04-10 18:15:00 UTC; unix
