# Generated by roxygen2: do not edit by hand

S3method(create_l1,glmerMod)
S3method(equation,character)
S3method(equation,default)
S3method(extract_eq,default)
S3method(extract_eq,forecast_ARIMA)
S3method(extract_eq,glmerMod)
S3method(extract_eq,list)
S3method(extract_eq,lmerMod)
S3method(extract_eq,model_fit)
S3method(extract_eq,workflow)
S3method(format,equation)
S3method(knit_print,equation)
S3method(print,equation)
S3method(print,inline_equation)
export(eqOutput)
export(eq_)
export(eq__)
export(equation)
export(extract_eq)
export(preview_eq)
export(renderEq)
importFrom(knitr,asis_output)
importFrom(knitr,is_html_output)
importFrom(knitr,is_latex_output)
importFrom(knitr,knit_print)
importFrom(shiny,createRenderFunction)
importFrom(shiny,helpText)
importFrom(shiny,htmlOutput)
importFrom(shiny,installExprFunction)
importFrom(shiny,withMathJax)
importFrom(stats,coef)
importFrom(stats,formula)
importFrom(stats,setNames)
importFrom(stats,terms)
importFrom(utils,tail)
