#' @keywords internal
#' @importFrom stats terms formula coef setNames
#' @importFrom knitr knit_print asis_output is_html_output is_latex_output
#' @importFrom utils tail
#' @importFrom shiny installExprFunction createRenderFunction htmlOutput
#'   withMathJax helpText

"_PACKAGE"

utils::globalVariables("func")

# The following block is used by usethis to automatically manage
# roxygen namespace tags. Modify with care!
## usethis namespace: start
## usethis namespace: end
NULL
